package com.blackberry.workspaces.sdk.api.examples;

import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

import com.blackberry.workspaces.sdk.api.APISession;
import com.blackberry.workspaces.sdk.api.DownloadManager;
import com.blackberry.workspaces.sdk.api.enums.DownloadTypes;

/**
 * Examples of downloading a file
 * @author tasfaw
 *
 */
public class DownloadFilesExample {
            private APISession apiSession;

            /**
             * Creates an instances of the DownloadFilesExample class
             * 
             * @param apiSession An ApiSession instance to be used.
             */
            public DownloadFilesExample(APISession apiSession)
            {
                this.apiSession = apiSession;
            }

            /**
             * DownloadFileById
             * 
             * @param docId
             * @param roomId
             * @param destinationPath
             * @param destinationDocName
             */
            public void downloadFileById(String docId, int roomId, String destinationPath, String destinationDocName)
            {
                Date lastUpdateTime = new Date();

                // START SNIPPET: devGuide18
                // Get an instance of DownloadManager
                DownloadManager downloadManager = apiSession.getDownloadManager();

                // A call to the DownloadFileById
                try {
                    downloadManager.downloadFileById(docId, "", roomId, destinationPath,
                            destinationDocName,lastUpdateTime,
                            true, true, DownloadTypes.MAX_ALLOWED);
                } catch (IOException e) {
                    // TODO Auto-generated catch block
                    e.printStackTrace();
                }
                // END SNIPPET: devGuide18
            }

            /**
             * DownloadFileByName
             * 
             * @param roomId
             * @param folderPath
             * @param docName
             * @param destinationPath
             * @param destinationDocName
             */
            public void downloadFileByName(int roomId, String folderPath, String docName,
                    String destinationPath, String destinationDocName)
            {
                 Calendar c  = Calendar.getInstance();
                 try {
                    c.setTime(new SimpleDateFormat("MM/dd/yyyy").parse("11/11/2011"));
                } catch (ParseException e) {
                    // TODO Auto-generated catch block
                    e.printStackTrace();
                }
                 Date lastUpdateTime = c.getTime();

                 // START SNIPPET: devGuide19
                // Get an instance of DownloadManager
                DownloadManager downloadManager = apiSession.getDownloadManager();

                // A call to the DownloadFileByName
                try {
                    downloadManager.downloadFileByName(roomId, folderPath, docName,
                        destinationPath, destinationDocName, lastUpdateTime);
                } catch (IOException e) {
                    // TODO Auto-generated catch block
                    e.printStackTrace();
                }
                // END SNIPPET: devGuide19
            }

            /**
             * DownloadFileToBuffer
             * 
             * @param docId
             * @return
             */
            public byte[] downloadFileToBuffer(String docId)
            {
                // START SNIPPET: devGuide20
                // Get an instance of DownloadManager
                DownloadManager downloadManager = apiSession.getDownloadManager();

                // A call to the DownloadFileToBuffer
                byte[] buffer = downloadManager.downloadFileToBuffer(docId,
                        DownloadTypes.ORIGINAL);

                // END SNIPPET: devGuide20
                return buffer;
            }

            /**
             * Download the protected version of the document with the given Id to the destination path.
             * 
             * @param docId
             * @param destinationPath
             * @param docName
             */
            public void downloadProtectedFileById(String docId, String destinationPath, String docName)
            {
                // Get an instance of DownloadManager
                DownloadManager downloadManager = apiSession.getDownloadManager();

                // A call to the DownloadProtectedFileById
                try {
                    downloadManager.downloadProtectedFileById(docId, destinationPath, docName);
                } catch (IOException e) {
                    // TODO Auto-generated catch block
                    e.printStackTrace();
                }
            }
    }

