package com.blackberry.workspaces.sdk.api.examples;

import java.security.PrivateKey;

import com.blackberry.workspaces.sdk.api.APISession;

/*
 * This class represents an example of using service account authentication with
 * WatchDox.
 * 
 * To create the keystore, run the following command:
 * 
 * keytool -genkey -alias <ALIAS> -keyalg RSA -keystore <KEYSTORE FILE NAME> -keysize 2048
 * 
 * It will prompt you for some info, including the password- remember it. This will create the private key and
 * a self-signed certificate from which you will get the public key to copy to the WatchDox server, using this command:
 * 
 * keytool -list -rfc -keystore <KEYSTORE FILE NAME> -alias <ALIAS> -storepass <KEYSTORE PASSWORD>
 * 
 * Copy everything between -----BEGIN CERTIFICATE----- and -----END CERTIFICATE----- to the service account
 * on the WatchDox server.
 * 
 * When you run this example, you will see an auth token printed. You would use this in an auth header like this:
 * 
 * Authorization: Bearer expires=XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
 * 
 */

public class ServiceAccountAuthenticationExample
{
    private APISession apiSession;

    /**
     * Creates an instances of the WorkspacesExample class
     * @param apiSession An ApiSession instance to be used.
     */
    public ServiceAccountAuthenticationExample(APISession apiSession)
    {
        this.apiSession = apiSession;
    }

  /*
   * Main method for driving the example.
   * Returns an auth token(beginning with 'expires=") for use in an auth header like this:
   * 
   * Authorization: Bearer expires=XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
   * 
   * userEmail - the email associated with the service account
   * issuer - the WatchDox-generated ID associated with the service account that will be used
   * durationMinutes - how the token will be valid, in minutes
   * pKey - the PrivateKey to the keystore
   * encryptionAlgorithm - the encryption to use in signing the data
   */
/**
 * 
 * @param userEmail
 * @param issuer
 * @param durationMinutes
 * @param pKey
 * @param encryptionAlgorithm
 * @return
 */
  public String generateToken(String userEmail, String issuer, int durationMinutes, PrivateKey pKey, String encryptionAlgorithm)
  {
    return apiSession.getServiceAccountToken(userEmail, issuer, durationMinutes, pKey, encryptionAlgorithm);
  }
}
